@@ -5,7 +5,7 @@ context("Reveal Outcomes")
 
 
 test_that("Reveal Outcomes", {
-  my_population <- declare_population(N = 1000, u = rnorm(N))
+  my_population <- declare_model(N = 1000, u = rnorm(N))
 
   my_sampling <- declare_sampling(S = complete_rs(N, n = 100))
 
@@ -21,9 +21,9 @@ test_that("Reveal Outcomes", {
 
   my_estimator <- declare_estimator(Y ~ Z, inquiry = my_inquiry)
 
-  my_reveal <- declare_reveal()
+  my_measurement <- declare_measurement(Y = reveal_outcomes(Y ~ Z)) 
 
-  my_design <- my_population + my_potential_outcomes + my_inquiry + my_sampling + my_assignment + my_reveal + my_estimator
+  my_design <- my_population + my_potential_outcomes + my_inquiry + my_sampling + my_assignment + my_measurement + my_estimator
 
   dat <- draw_data(my_design)
 
@@ -35,24 +35,26 @@ test_that("Reveal Outcomes", {
 })
 
 test_that("Reveal Outcomes NSE for assignment / outcome variables ", {
-  my_population <- declare_population(N = 500, noise = 1:N)
+  my_population <- declare_model(N = 500, noise = 1:N)
 
   my_potential_outcomes <- declare_potential_outcomes(Y_Z_0 = noise, Y_Z_1 = noise + 1)
 
   my_assignment <- declare_assignment(Z = complete_ra(N, prob = 1))
+  
+  my_measurement <- declare_measurement(Y = reveal_outcomes(Y ~ Z)) 
 
-  design <- my_population + my_potential_outcomes + my_assignment + declare_reveal()
+  design <- my_population + my_potential_outcomes + my_assignment + my_measurement
 
   df1 <- draw_data(design)
 
 
   design <- my_population + my_potential_outcomes + my_assignment +
-    declare_reveal(assignment_variables = Z, outcome_variables = Y)
+    declare_measurement(Y = reveal_outcomes(Y ~ Z))
 
   df2 <- draw_data(design)
 
   design <- my_population + my_potential_outcomes + my_assignment +
-    declare_reveal(assignment_variable = "Z", outcome_variable = "Y")
+    declare_measurement(Y = reveal_outcomes(Y ~ Z))
 
   df3 <- draw_data(design)
 
@@ -63,17 +65,17 @@ test_that("Reveal Outcomes NSE for assignment / outcome variables ", {
 test_that("reveal multiple outcomes works", {
   N <- 25
 
-  my_population <- declare_population(N = N, noise = 1:N)
+  my_population <- declare_model(N = N, noise = 1:N)
   my_potential_outcomes1 <- declare_potential_outcomes(formula = Y1 ~ Z * .25, conditions = c(0, 1))
   my_potential_outcomes2 <- declare_potential_outcomes(formula = Y2 ~ Z * .5 + 3, conditions = c(0, 1))
   my_assignment <- declare_assignment(Z = complete_ra(N, prob = 1))
 
   design <- my_population + my_potential_outcomes1 + my_potential_outcomes2 + my_assignment +
-    declare_reveal(outcome_variables = c(Y1, Y2))
+    declare_measurement(Y1 = reveal_outcomes(Y1 ~ Z), Y2 = reveal_outcomes(Y2 ~ Z)) 
   df1 <- draw_data(design)
 
   design <- my_population + my_potential_outcomes1 + my_potential_outcomes2 + my_assignment +
-    declare_reveal(outcome_variables = c("Y1", "Y2"))
+    declare_measurement(Y1 = reveal_outcomes(Y1 ~ Z), Y2 = reveal_outcomes(Y2 ~ Z)) 
   df2 <- draw_data(design)
 
   expect_identical(df1, df2)
@@ -82,7 +84,7 @@ test_that("reveal multiple outcomes works", {
 test_that("declare_reveal custom handler works", {
   N <- 25
 
-  my_population <- declare_population(N = N, noise = rnorm(N))
+  my_population <- declare_model(N = N, noise = rnorm(N))
   my_assignment <- declare_assignment(Z = complete_ra(N, m = 10))
 
   my_outcome_function <- function(data) {
@@ -98,22 +100,23 @@ test_that("declare_reveal custom handler works", {
 
 test_that("missing PO stops", {
   expect_error(
-    declare_reveal(outcome_variables = foo, assignment_variables = extra)(sleep)
+    declare_measurement(foo = reveal_outcomes(foo ~ extra))(sleep)
   )
 })
 
 test_that("Not all Potential outcome columns present", {
+  set.seed(4)
   df <- data.frame(Z = sample(1:3, 100, replace = TRUE), Y_Z_0 = 1:100, Y_Z_1 = 1:100)
 
   expect_error(
-    declare_reveal()(df),
+    declare_measurement(Y = reveal_outcomes(Y ~ Z))(df),
     "Y_Z_3"
   )
 })
 
 
 test_that("Single outcome, multiple assn", {
-  population <- declare_population(
+  population <- declare_model(
     blocks = fabricatr::add_level(
       N = 40,
       block_shock = rnorm(N)
@@ -139,7 +142,7 @@ test_that("Single outcome, multiple assn", {
     B = block_ra(blocks = A + 10 * as.numeric(blocks))
   )
 
-  design <- population + potential_outcomes + assign_A + assign_B + declare_reveal(outcome_variables = Y, assignment_variables = c(A, B))
+  design <- population + potential_outcomes + assign_A + assign_B + declare_measurement(Y = reveal_outcomes(Y ~ A + B))
 
   dd <- draw_data(design)
 
@@ -159,3 +162,4 @@ test_that("handler rrror on symbols", {
     attrition_variables = as.symbol("R")
   ))
 })
+
